@@ -4,7 +4,8 @@ from pulpcore.plugin import PulpPluginAppConfig
 class PulpCertGuardPluginAppConfig(PulpPluginAppConfig):
     """App config for cert guard plugin."""
 
-    name = 'pulp_certguard.app'
-    label = 'certguard'
-    version = '1.5.8'
+    name = "pulp_certguard.app"
+    label = "certguard"
+    version = "1.6.0"
     python_package_name = "pulp-certguard"
+    domain_compatible = True
