@@ -7,7 +7,7 @@ from .serializers import RHSMCertGuardSerializer, X509CertGuardSerializer
 class RHSMCertGuardViewSet(ContentGuardViewSet):
     """RHSMCertGuard API Viewsets."""
 
-    endpoint_name = 'rhsm'
+    endpoint_name = "rhsm"
     queryset = RHSMCertGuard.objects.all()
     serializer_class = RHSMCertGuardSerializer
     filterset_class = ContentGuardFilter
@@ -16,7 +16,7 @@ class RHSMCertGuardViewSet(ContentGuardViewSet):
 class X509CertGuardViewSet(ContentGuardViewSet):
     """X509CertGuard API Viewsets."""
 
-    endpoint_name = 'x509'
+    endpoint_name = "x509"
     queryset = X509CertGuard.objects.all()
     serializer_class = X509CertGuardSerializer
     filterset_class = ContentGuardFilter
